rank_to_pg: Rank to Paygrades

View source: R/rank_to_pg.R

rank_to_pgR Documentation

Rank to Paygrades

Description

Rank to Paygrades

Usage

rank_to_pg(df, service)

Arguments

df

a dataframe of ranks and possibly services

service

either "Multi", in which case columns "service" and "rank" must be present in df, or one of "Army", "Air Force", "Navy", "Coast Guard", in which case column rank must be present in df

Value

This function returns a dataframe with an additional column for paygrade

Author(s)

Bjorn Kallerud


bjornkallerud/dataOPS documentation built on Oct. 1, 2022, 10:42 a.m.