| rank_to_pg | R Documentation |
Rank to Paygrades
rank_to_pg(df, service)
df |
a dataframe of ranks and possibly services |
service |
either "Multi", in which case columns "service" and "rank" must be present in df, or one of "Army", "Air Force", "Navy", "Coast Guard", in which case column rank must be present in df |
This function returns a dataframe with an additional column for paygrade
Bjorn Kallerud
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.